from test.bases import WorldTestBase

class DredgeTestBase(WorldTestBase):
    game = "DREDGE"